@@ -22,7 +22,7 @@ class Trigger(ABC):
     def add_listener(self, listener):
         self.listeners.add(listener)
 
-    def is_valid(self):
+    def is_valid(self) -> bool:
         return self.invoker is not None
 
     def invoke(self, item_registry: ItemRegistry):
@@ -54,6 +54,9 @@ class Trigger(ABC):
     def __eq__(self, other):
         return self.__str__() == other.__str__()
 
+    def __lt__(self, other):
+        return self.__str__() < other.__str__()
+
     def __str__(self):
         return self.expression + " -> " + self.module + "#" + self.name
 
@@ -81,7 +84,7 @@ class ItemChangedTrigger(Trigger):
         self.operation = operation
         super().__init__(expression, func)
 
-    def matches(self, event):
+    def matches(self, event) -> bool:
         topic = event.get("topic", "")
         if topic.startswith('openhab') or topic.startswith('smarthome'):
             try:
@@ -107,7 +110,6 @@ class Execution:
     datetime: datetime
     error: Optional[Exception] = None
 
-
     def __lt__(self, other):
         return self.datetime < other.datetime
 
